@@ -26,3 +26,6 @@ class ItemConfig:
             return self.key
 
         return self.extract_names[0]
+
+    class Config:
+        arbitrary_types_allowed = True
