@@ -1,12 +1,13 @@
 from dataclasses import dataclass
 from typing import List, Dict, Tuple, Optional, Sequence
 
-from scipy.optimize import minimize
-from sympy import Eq, sympify, IndexedBase
+from scipy.optimize import minimize, OptimizeResult
+from sympy import Eq, sympify, IndexedBase, Expr, solve, Indexed
 import pandas as pd
 import numpy as np
 from sympy.core.numbers import NaN
 
+from finstmt.config_manage.statements import StatementsConfigManager
 from finstmt.exc import BalanceSheetNotBalancedException, MissingDataException, InvalidForecastEquationException
 from finstmt.forecast.main import Forecast
 from finstmt.config_manage.data import _key_pct_of_key
@@ -23,7 +24,7 @@ from finstmt.resolver.base import ResolverBase
 # could handle more operations with the plugs, and the math could be more separated
 # from the finance logic.
 from finstmt.resolver.solve import PLUG_SCALE, solve_equations, sympy_dict_to_results_dict, _x_arr_to_plug_solutions, \
-    _symbolic_to_matrix, _solve_eqs_with_plug_solutions
+    _symbolic_to_matrix, _solve_eqs_with_plug_solutions, _get_indexed_symbols
 
 
 class ForecastResolver(ResolverBase):
@@ -44,21 +45,15 @@ class ForecastResolver(ResolverBase):
 
     def resolve_balance_sheet(self):
         logger.info('Balancing balance sheet')
-        x_arrs = []
-        plug_keys = []
-        for config in self.plug_configs:
-            x_arrs.append(self.results[config.key].values)
-            plug_keys.append(config.key)
-        x0 = np.concatenate(x_arrs) / PLUG_SCALE
 
         solutions_dict = self.subs_dict.copy()
         new_solutions = resolve_balance_sheet(
-            x0,
+            self.plug_x0,
             self.solve_eqs,
-            plug_keys,
+            self.plug_keys,
             self.subs_dict,
             self.forecast_dates,
-            self.stmts.all_config_items,
+            self.stmts.config,
             self.stmts.config.sympy_namespace,
             self.bs_diff_max,
         )
@@ -70,7 +65,10 @@ class ForecastResolver(ResolverBase):
         if self.balance:
             solutions_dict = self.resolve_balance_sheet()
         else:
-            solutions_dict = solve_equations(self.solve_eqs, self.subs_dict)
+            if self.solve_eqs:
+                solutions_dict = solve_equations(self.solve_eqs, self.subs_dict)
+            else:
+                solutions_dict = self.subs_dict
 
         new_results = sympy_dict_to_results_dict(
             solutions_dict, self.forecast_dates, self.stmts.all_config_items, t_offset=1
@@ -82,8 +80,12 @@ class ForecastResolver(ResolverBase):
                 self.forecast_dict[config.key].to_manual(use_levels=True, replacements=new_results[config.key].values)
 
         all_results = pd.concat(list(new_results.values()), axis=1).T
-        inc_df = self.stmts.income_statements.__class__.from_df(all_results, self.stmts.income_statements.config.items)
-        bs_df = self.stmts.balance_sheets.__class__.from_df(all_results, self.stmts.balance_sheets.config.items)
+        inc_df = self.stmts.income_statements.__class__.from_df(
+            all_results, self.stmts.income_statements.config.items, disp_unextracted=False
+        )
+        bs_df = self.stmts.balance_sheets.__class__.from_df(
+            all_results, self.stmts.balance_sheets.config.items, disp_unextracted=False
+        )
 
         # type ignore added because for some reason mypy is not picking up structure
         # correctly since it is a dataclass
@@ -102,7 +104,7 @@ class ForecastResolver(ResolverBase):
                 lhs = sympify(config.key + '[t]', locals=self.stmts.config.sympy_namespace)
                 if config.expr_str is not None:
                     rhs = self.stmts.config.expr_for(config.key)
-                elif config.forecast_config.pct_of is not None:
+                elif config.forecast_config.pct_of is not None and config.forecast_config.make_forecast:
                     key_pct_of_key = _key_pct_of_key(config.key, config.forecast_config.pct_of)
                     rhs = sympify(f'{config.forecast_config.pct_of}[t] * {key_pct_of_key}[t]',
                                   locals=self.stmts.config.sympy_namespace)
@@ -121,7 +123,12 @@ class ForecastResolver(ResolverBase):
         for period in range(1, self.num_periods):
             this_t_eqs = [eq.subs({self.t: period}) for eq in t_eqs]
             out_eqs.extend(this_t_eqs)
-        return out_eqs
+
+        all_hardcoded = _x_arr_to_plug_solutions(self.plug_x0, self.plug_keys, self.stmts.config.sympy_namespace)
+        all_hardcoded.update(self.sympy_subs_dict)
+        new_eqs = _get_equations_reformed_for_needed_solutions(out_eqs, all_hardcoded, self.stmts.config)
+
+        return new_eqs
 
     @property
     def num_periods(self) -> int:
@@ -183,6 +190,20 @@ class ForecastResolver(ResolverBase):
     def plug_configs(self) -> List[ItemConfig]:
         return [conf for conf in self.stmts.all_config_items if conf.forecast_config.plug]
 
+    @property
+    def plug_keys(self) -> List[str]:
+        return [config.key for config in self.plug_configs]
+
+    @property
+    def plug_x0(self) -> np.array:
+        x_arrs = []
+        plug_keys = []
+        for config in self.plug_configs:
+            x_arrs.append(self.results[config.key].values)
+            plug_keys.append(config.key)
+        x0 = np.concatenate(x_arrs) / PLUG_SCALE
+        return x0
+
 
 @dataclass
 class PlugResult:
@@ -191,35 +212,47 @@ class PlugResult:
 
 def resolve_balance_sheet(x0: np.ndarray, eqs: List[Eq], plug_keys: Sequence[str],
                           subs_dict: Dict[IndexedBase, float], forecast_dates: pd.DatetimeIndex,
-                          item_configs: List[ItemConfig],
+                          config: StatementsConfigManager,
                           sympy_namespace: Dict[str, IndexedBase], bs_diff_max: float) -> Dict[IndexedBase, float]:
     plug_solutions = _x_arr_to_plug_solutions(x0, plug_keys, sympy_namespace)
-    solve_exprs = []
-    to_solve_for = []
+    all_to_solve: Dict[IndexedBase, Expr] = {}
     for eq in eqs:
         expr = eq.rhs - eq.lhs
         if expr == NaN():
             raise InvalidForecastEquationException(f'got NaN forecast equation. LHS: {eq.lhs}, RHS: {eq.rhs}')
-        solve_exprs.append(expr)
-        to_solve_for.append(eq.lhs)
+        if eq.lhs in all_to_solve:
+            raise InvalidForecastEquationException(
+                f'got multiple equations to solve for {eq.lhs}. Already had {all_to_solve[eq.lhs]}, now got {expr}'
+            )
+        all_to_solve[eq.lhs] = expr
     for sol_dict in [subs_dict, plug_solutions]:
         # Plug solutions second here so that they are at end of array
         for lhs, rhs in sol_dict.items():
             expr = rhs - lhs
             if expr == NaN():
                 raise MissingDataException(f'got NaN for {lhs} but that is needed for resolving the forecast')
-            solve_exprs.append(expr)
-            to_solve_for.append(lhs)
-    to_solve_for = list(set(to_solve_for))
+            if lhs in all_to_solve:
+                existing_value = all_to_solve[lhs]
+                if isinstance(existing_value, float):
+                    had_message = f'forecast/plug value of {existing_value}'
+                else:
+                    had_message = f'equation of {existing_value}'
+                raise InvalidForecastEquationException(
+                    f'got forecast/plug value for {lhs} but already had an existing {had_message}, now got {expr}'
+                )
+            all_to_solve[lhs] = expr
+    to_solve_for = list(all_to_solve.keys())
+    solve_exprs = list(all_to_solve.values())
+    _check_for_invalid_system_of_equations(eqs, subs_dict, plug_solutions, to_solve_for, solve_exprs)
     eq_arrs = _symbolic_to_matrix(solve_exprs, to_solve_for)
 
     result = PlugResult()
-    res = None
+    res: Optional[OptimizeResult] = None
     try:
         res = minimize(
             _resolve_balance_sheet_check_diff,
             x0,
-            args=(eq_arrs, forecast_dates, item_configs, to_solve_for, bs_diff_max, result),
+            args=(eq_arrs, forecast_dates, to_solve_for, bs_diff_max, result),
             bounds=[(0, None) for _ in range(len(x0))],  # all positive
             method='TNC',
             options=dict(
@@ -231,20 +264,31 @@ def resolve_balance_sheet(x0: np.ndarray, eqs: List[Eq], plug_keys: Sequence[str
     if result.res is None:
         message: Optional[str]
         if res is not None:
-            message = f'final solution {res.x * PLUG_SCALE} still could not meet max difference of {bs_diff_max}'
+            plug_solutions = _x_arr_to_plug_solutions(res.x, plug_keys, sympy_namespace)
+            avg_error = (res.fun ** 2 / len(res.x)) ** 0.5
+            message = (
+                f'final solution {plug_solutions} still could not meet max difference of '
+                f'${bs_diff_max:,.0f}. Average difference was ${avg_error:,.0f}.\nIf the make_forecast or plug '
+                f'configuration for any items were changed, ensure that changes in {plug_keys} can flow through '
+                f'to Total Assets and Total Liabilities and Equity. For example, if make_forecast=True for Total Debt '
+                f'and make_forecast=False for ST Debt, then using LT debt as a plug will not work as ST debt will '
+                f'go down when LT debt goes up.\nOtherwise, consider '
+                f'passing bs_diff_max to .forecast at a value greater than {avg_error:,.0f}, or pass '
+                f'balance=False to skip balancing entirely.'
+            )
         else:
             message = None
         raise BalanceSheetNotBalancedException(message)
     plug_solutions = _x_arr_to_plug_solutions(result.res, plug_keys, sympy_namespace)
     solutions_dict = _solve_eqs_with_plug_solutions(
-        eqs, plug_solutions, subs_dict, forecast_dates, item_configs
+        eqs, plug_solutions, subs_dict, forecast_dates, config.items
     )
     return solutions_dict
 
 
 def _resolve_balance_sheet_check_diff(x: np.ndarray, eq_arrs: Tuple[np.ndarray, np.ndarray],
                                       forecast_dates: pd.DatetimeIndex,
-                                      item_configs: List[ItemConfig], solve_for: Sequence[IndexedBase],
+                                      solve_for: Sequence[IndexedBase],
                                       bs_diff_max: float, res: PlugResult):
     A_arr, b_arr = eq_arrs
     b_arr[-len(x):] = -x * PLUG_SCALE  # plug solutions with new X values
@@ -276,3 +320,71 @@ def _resolve_balance_sheet_check_diff(x: np.ndarray, eq_arrs: Tuple[np.ndarray,
 
 class BalanceSheetBalancedException(Exception):
     pass
+
+
+def _check_for_invalid_system_of_equations(eqs: List[Eq], subs_dict: Dict[IndexedBase, float],
+                                           plug_solutions: Dict[IndexedBase, float],
+                                           to_solve_for: List[IndexedBase], solve_exprs: List[Expr]):
+    if len(to_solve_for) == len(solve_exprs):
+        # Equations seem valid, just return
+        return
+
+    # Invalid equations, figure out why
+    eq_lhs = {eq.lhs for eq in eqs}
+    subs_lhs = {key for key in subs_dict}
+    plugs_lhs = {key for key in plug_solutions}
+    message = f'Got {len(to_solve_for)} items to solve for with {len(solve_exprs)} equations. '
+    eq_subs_overlap = eq_lhs.intersection(subs_lhs)
+    if eq_subs_overlap:
+        message += f'Got {eq_subs_overlap} which overlap between the equations and the calculated values. '
+    eq_plugs_overlap = eq_lhs.intersection(plugs_lhs)
+    if eq_plugs_overlap:
+        message += f'Got {eq_plugs_overlap} which overlap between the equations and the plug values. '
+    subs_plugs_overlap = subs_lhs.intersection(plugs_lhs)
+    if subs_plugs_overlap:
+        message += f'Got {subs_plugs_overlap} which overlap between the calculated values and the plug values. '
+    raise InvalidForecastEquationException(message)
+
+
+def _get_equations_reformed_for_needed_solutions(eqs: Sequence[Eq], all_hardcoded: Dict[IndexedBase, float],
+                                                 config: StatementsConfigManager) -> List[Eq]:
+    new_eqs = []
+    for eq in eqs:
+        if eq.lhs in all_hardcoded:
+            # Got a calculated item which has also been set with make_forecast=True or as plug=True
+            # Solve the equation to see if there is another variable we can set as the lhs which
+            # has make_forecast=False and plug=False
+            selected_lhs: Optional[IndexedBase] = None
+            for sym in _get_indexed_symbols(eq.rhs):
+                if sym not in all_hardcoded:
+                    selected_lhs = sym
+            if selected_lhs is None:
+                # Invalid forecast, need to display useful message to the user to fix it.
+                # Need to get the original unsubbed equation, as possible variables the user could adjust might
+                # have been substituted out of the equation
+                key = str(eq.lhs.base)
+                orig_expr = config.expr_for(key)
+                orig_eq = Eq(eq.lhs, orig_expr)
+
+                possible_fix_strs = []
+                possible_symbols = _get_indexed_symbols(orig_eq)
+                for sym in possible_symbols:
+                    sym_key = str(sym.base)
+                    fix_str = f'\tstmts.config.update("{sym_key}", ["forecast_config", "make_forecast"], False)\n\t' \
+                              f'stmts.config.update("{sym_key}", ["forecast_config", "plug"], False)'
+                    possible_fix_strs.append(fix_str)
+                possible_fix_str = '\nor,\n'.join(possible_fix_strs)
+
+                raise InvalidForecastEquationException(
+                    f'{eq.lhs} has been set with make_forecast=True or plug=True and yet it is a calculated '
+                    f'item. Tried to re-express {orig_eq} in terms of another variable which is not forecasted or '
+                    f'plugged but they all are. Set one of {_get_indexed_symbols(orig_eq)} '
+                    f'with make_forecast=False and plug=False.\n\nPossible fixes:\n{possible_fix_str}'
+                )
+            # Another variable in the original equation is not forecasted/plugged. Re-express the equation in
+            # terms of that variable
+            solution = solve(eq, selected_lhs)[0]
+            new_eqs.append(Eq(selected_lhs, solution))
+        else:
+            new_eqs.append(eq)
+    return new_eqs
\ No newline at end of file
